var group__cpp__entities =
[
    [ "flecs::entity", "structflecs_1_1entity.html", [
      [ "entity", "structflecs_1_1entity.html#ac475621a5fb9513885c12474ba7ffd67", null ],
      [ "entity", "structflecs_1_1entity.html#a8baaadf7cffb365c70109d5b00e54fea", null ],
      [ "entity", "structflecs_1_1entity.html#a5507fae8c3f326e957f468372b63b322", null ],
      [ "entity", "structflecs_1_1entity.html#ac343dbb0c6a3cd44bd97863127a1c2a0", null ],
      [ "entity", "structflecs_1_1entity.html#a9d2361efe2ea358b3bd0728408ced507", null ],
      [ "child", "structflecs_1_1entity.html#af6ff23d1598489b6213284a29dcd2a9a", null ],
      [ "clear", "structflecs_1_1entity.html#a3a115a6cbd08c6de08e0ecfe8608ccbb", null ],
      [ "destruct", "structflecs_1_1entity.html#a05c1af95015764fc68aa790d274f4462", null ],
      [ "ensure", "structflecs_1_1entity.html#a8fca9021f1846e165eba581adaee64ba", null ],
      [ "ensure", "structflecs_1_1entity.html#af332067cf1fc966681c74f93dbfd3ba0", null ],
      [ "ensure", "structflecs_1_1entity.html#a9c49f2a9835015eaa9836c3d5d8e286e", null ],
      [ "ensure", "structflecs_1_1entity.html#a6489d776974b5cd87b5e84f557b16a79", null ],
      [ "ensure", "structflecs_1_1entity.html#a32ec3d1b9da53261fc3981c1f7e2277b", null ],
      [ "ensure_second", "structflecs_1_1entity.html#a969ca3768656ad39ac63fced5ccadf91", null ],
      [ "from_json", "structflecs_1_1entity.html#ga47edfb42247b4e13c3c1c07658be724e", null ],
      [ "from_json", "group__cpp__addons__json.html#ga47edfb42247b4e13c3c1c07658be724e", null ],
      [ "get_ref", "structflecs_1_1entity.html#a0cedfc7447654b086c0e6a9d6086515f", null ],
      [ "get_ref", "structflecs_1_1entity.html#aee5caacc56de16ca8198f4bafb6bc90c", null ],
      [ "get_ref_w_id", "structflecs_1_1entity.html#a45bcfbaa8eea7b8cfeaea9921367890f", null ],
      [ "modified", "structflecs_1_1entity.html#a8cb796e5781775753b5ca8fd9d85b59e", null ],
      [ "modified", "structflecs_1_1entity.html#a1d7203975cf6644f81ca20b911dcb12c", null ],
      [ "modified", "structflecs_1_1entity.html#a34ed2767da35c164134b21f4d4a083b4", null ],
      [ "modified", "structflecs_1_1entity.html#a46b645e7cdfe073077b392231e231f10", null ],
      [ "modified", "structflecs_1_1entity.html#a0e494b2a380e94acb8a15e10eb031170", null ],
      [ "set_child_order", "structflecs_1_1entity.html#ad552d436290984e56b5327afc33c3833", null ],
      [ "view", "structflecs_1_1entity.html#acc0abe24401b9c3fb54187258a7edb64", null ]
    ] ],
    [ "flecs::entity_view", "structflecs_1_1entity__view.html", [
      [ "entity_view", "structflecs_1_1entity__view.html#a4a8996a0d9c528294da5bc6f22873841", null ],
      [ "entity_view", "structflecs_1_1entity__view.html#a0d5b19b619f9d78bf53f9ed74b180173", null ],
      [ "alert_count", "structflecs_1_1entity__view.html#gaf25d5bcded81553d04a0ff462ac6a05e", null ],
      [ "alert_count", "group__cpp__addons__alerts.html#gaf25d5bcded81553d04a0ff462ac6a05e", null ],
      [ "children", "structflecs_1_1entity__view.html#aef427d1dbbd9284cbc59a05ed94011db", null ],
      [ "children", "structflecs_1_1entity__view.html#a659680859e43371687f880b0781b6ef9", null ],
      [ "children", "structflecs_1_1entity__view.html#abedd0dd7e0b9dae8e9cc25d717ee4e3e", null ],
      [ "depth", "structflecs_1_1entity__view.html#a3ee3934868dc56595448dad7413ea926", null ],
      [ "depth", "structflecs_1_1entity__view.html#a0d7ed298781771ceda93212b0bfa8905", null ],
      [ "doc_brief", "structflecs_1_1entity__view.html#gabf672e81afeddec4a4e2c0f8250ff021", null ],
      [ "doc_brief", "group__cpp__addons__doc.html#gabf672e81afeddec4a4e2c0f8250ff021", null ],
      [ "doc_color", "structflecs_1_1entity__view.html#gac9ee07df2042efd85259a7cf2c4e55f6", null ],
      [ "doc_color", "group__cpp__addons__doc.html#gac9ee07df2042efd85259a7cf2c4e55f6", null ],
      [ "doc_detail", "structflecs_1_1entity__view.html#gaad57d5f8523631450f0e3ea083fb0d35", null ],
      [ "doc_detail", "group__cpp__addons__doc.html#gaad57d5f8523631450f0e3ea083fb0d35", null ],
      [ "doc_link", "structflecs_1_1entity__view.html#gaa537a0f49dbd7c563900f2480f85d6a0", null ],
      [ "doc_link", "group__cpp__addons__doc.html#gaa537a0f49dbd7c563900f2480f85d6a0", null ],
      [ "doc_name", "structflecs_1_1entity__view.html#ga53dd532bce312cc69414e44c4cb9f938", null ],
      [ "doc_name", "group__cpp__addons__doc.html#ga53dd532bce312cc69414e44c4cb9f938", null ],
      [ "doc_uuid", "structflecs_1_1entity__view.html#gaa9f623f19cb2338d558dc5270fc4926e", null ],
      [ "doc_uuid", "group__cpp__addons__doc.html#gaa9f623f19cb2338d558dc5270fc4926e", null ],
      [ "each", "structflecs_1_1entity__view.html#ae097252480204e7488bf23da874d439b", null ],
      [ "each", "structflecs_1_1entity__view.html#a9fdf9fb51173722f07ce3c5b5011ba66", null ],
      [ "each", "structflecs_1_1entity__view.html#a2bac314f5513c5c00257177865d045a9", null ],
      [ "each", "structflecs_1_1entity__view.html#ae7b068aadd61aabe6734061bd8465224", null ],
      [ "emit", "structflecs_1_1entity__view.html#a5dbe98d0b92a17ef92636d9fd1f71bf1", null ],
      [ "emit", "structflecs_1_1entity__view.html#a5dbe98d0b92a17ef92636d9fd1f71bf1", null ],
      [ "emit", "structflecs_1_1entity__view.html#af5215e7570046d039308366041644e94", null ],
      [ "emit", "structflecs_1_1entity__view.html#af5215e7570046d039308366041644e94", null ],
      [ "emit", "structflecs_1_1entity__view.html#aa273be7c42fc44329c66ea26482ac08e", null ],
      [ "emit", "structflecs_1_1entity__view.html#a3bf7ef10028cc6227818d7183fa08b08", null ],
      [ "emit", "structflecs_1_1entity__view.html#a0eb8777cbca789b104bb4a26bcd8617c", null ],
      [ "emit", "structflecs_1_1entity__view.html#a0eb8777cbca789b104bb4a26bcd8617c", null ],
      [ "enabled", "structflecs_1_1entity__view.html#ae7c97528a4d08da20807a04624463bf4", null ],
      [ "enabled", "structflecs_1_1entity__view.html#a158c2844cb797c02f2a72b571665f531", null ],
      [ "enabled", "structflecs_1_1entity__view.html#afd8bbdfa0dbb5779eff473a6f9ee3ecd", null ],
      [ "enabled", "structflecs_1_1entity__view.html#a4b192b8fab230d7261532d43649c94b8", null ],
      [ "enabled", "structflecs_1_1entity__view.html#a81375e0d22cd83767c8ab63add2f3a7d", null ],
      [ "enqueue", "structflecs_1_1entity__view.html#a3d29e383da488d87cfd07f88d8258efd", null ],
      [ "enqueue", "structflecs_1_1entity__view.html#a3d29e383da488d87cfd07f88d8258efd", null ],
      [ "enqueue", "structflecs_1_1entity__view.html#aa5e7d1e6276b93de6590e5671ea42155", null ],
      [ "enqueue", "structflecs_1_1entity__view.html#aa5e7d1e6276b93de6590e5671ea42155", null ],
      [ "enqueue", "structflecs_1_1entity__view.html#abb4aa6711a182d00cf45f5329f0339d5", null ],
      [ "enqueue", "structflecs_1_1entity__view.html#a4ebd53ad482c45706a99273a75646eb5", null ],
      [ "enqueue", "structflecs_1_1entity__view.html#a6e4fb24de96dae91124d0c1b3ad0ab33", null ],
      [ "enqueue", "structflecs_1_1entity__view.html#a6e4fb24de96dae91124d0c1b3ad0ab33", null ],
      [ "get", "structflecs_1_1entity__view.html#a3d3a6d9a9008c2bcf94d11c53731be0f", null ],
      [ "get", "structflecs_1_1entity__view.html#ac0179e060eda565b0bb31f6ce8796b7e", null ],
      [ "get", "structflecs_1_1entity__view.html#aa6a01467b2411f9bec7d779740a8d372", null ],
      [ "get", "structflecs_1_1entity__view.html#ae49ff16148128ab73dba9360c45ae16a", null ],
      [ "get", "structflecs_1_1entity__view.html#aa31137457d97c65750a9d1ab1cab9ef1", null ],
      [ "get", "structflecs_1_1entity__view.html#add3902e51c4eb488c2730707bf7ff291", null ],
      [ "get", "structflecs_1_1entity__view.html#a6d8ffc799cac931f295eab7606cac54f", null ],
      [ "get", "structflecs_1_1entity__view.html#a63582be552a61044c514534eaf82eb97", null ],
      [ "get_constant", "structflecs_1_1entity__view.html#ac393176143b64ce79aed580fd987e721", null ],
      [ "get_mut", "structflecs_1_1entity__view.html#a1c009cbdd24cd4ec187ae7398065aa1b", null ],
      [ "get_mut", "structflecs_1_1entity__view.html#a1c064c250b00ff7498024c73ddcf3b43", null ],
      [ "get_mut", "structflecs_1_1entity__view.html#a2dba3c2f253d789794ac82e5eb7848c3", null ],
      [ "get_mut", "structflecs_1_1entity__view.html#a370ce1f8aafbed1f1d3e54a23cb3275e", null ],
      [ "get_mut", "structflecs_1_1entity__view.html#a9b0e66fe4276d2fbe5337df5bf853fb9", null ],
      [ "get_mut", "structflecs_1_1entity__view.html#a1afb751d27bc9ca4de094143bf4a58f7", null ],
      [ "get_mut", "structflecs_1_1entity__view.html#ac8e77d357e7322d698b25a7686f2c417", null ],
      [ "get_mut_second", "structflecs_1_1entity__view.html#a7b55d3c499a08d921c34495b1aad9461", null ],
      [ "get_mut_second", "structflecs_1_1entity__view.html#a6d241b0a822af13be853bbcdc0b33794", null ],
      [ "get_second", "structflecs_1_1entity__view.html#a3b499d598d51a0f28ae9d8adc24507d5", null ],
      [ "get_second", "structflecs_1_1entity__view.html#a3b3acc9198bb7c9adab1aa38549f8b4d", null ],
      [ "has", "structflecs_1_1entity__view.html#ab112fabea4a346faa70c6ab6893f32c5", null ],
      [ "has", "structflecs_1_1entity__view.html#ade76deb5597ef77c19a4f3f0e139a243", null ],
      [ "has", "structflecs_1_1entity__view.html#afd306a2dc2fce9b7ffc64c0281183944", null ],
      [ "has", "structflecs_1_1entity__view.html#a3ebf1add909969f0b898a50877d0b048", null ],
      [ "has", "structflecs_1_1entity__view.html#a86a680acf628f709c0074f9f6614b8c2", null ],
      [ "has", "structflecs_1_1entity__view.html#a1a6b7bbba2a12c79d6753c7cac947e05", null ],
      [ "has", "structflecs_1_1entity__view.html#a82d3d0641542d189693e148949a828f0", null ],
      [ "has_second", "structflecs_1_1entity__view.html#a5a3a6f912d0974252cb8b258eea9d5e3", null ],
      [ "id", "structflecs_1_1entity__view.html#ad3a1dbc2234988bdd6ceb2869df4366e", null ],
      [ "is_alive", "structflecs_1_1entity__view.html#aa483e6fe8c807328f0816214fcc5ea21", null ],
      [ "is_valid", "structflecs_1_1entity__view.html#a276f56db4d27735f67d071dbc62516e8", null ],
      [ "lookup", "structflecs_1_1entity__view.html#a6028645117ead3f771f5e98415034041", null ],
      [ "mut", "structflecs_1_1entity__view.html#ac3380480429088346adfdd8f3509269e", null ],
      [ "mut", "structflecs_1_1entity__view.html#a8aac26c944335f7b72129a7c0d3ccd1b", null ],
      [ "mut", "structflecs_1_1entity__view.html#af9aa998e4d4c73bf7500e10f97ff1616", null ],
      [ "name", "structflecs_1_1entity__view.html#a21546d910784627b55c3e16741697edf", null ],
      [ "owns", "structflecs_1_1entity__view.html#a877abf72bd966c3299dc060c196fddc7", null ],
      [ "owns", "structflecs_1_1entity__view.html#a3ba792f11fbf6839611b9b2eab63ab1c", null ],
      [ "owns", "structflecs_1_1entity__view.html#a672fe1de67f3920c6148129fa2d5ec05", null ],
      [ "owns", "structflecs_1_1entity__view.html#aba8ed0fb04be5887f6ec00858eea09a7", null ],
      [ "owns", "structflecs_1_1entity__view.html#a21cc266a1cfcb4d937404cba9da53d60", null ],
      [ "parent", "structflecs_1_1entity__view.html#a8ba4779dad826ead82587df06fff73df", null ],
      [ "path", "structflecs_1_1entity__view.html#a293786fdb95262227514b487097b81be", null ],
      [ "path_from", "structflecs_1_1entity__view.html#adfa01a1bf58d0cb8aa9f93d07d5b50a5", null ],
      [ "path_from", "structflecs_1_1entity__view.html#a754707326d689b1ddf3d0786c8b51488", null ],
      [ "range", "structflecs_1_1entity__view.html#a3087394555087588eaf0027f85ecf7af", null ],
      [ "symbol", "structflecs_1_1entity__view.html#a2ac9d92084ced61a79a1ce29622608dc", null ],
      [ "table", "structflecs_1_1entity__view.html#a74e475b5f47e7fc35c0a6e9521c6fa6d", null ],
      [ "target", "structflecs_1_1entity__view.html#afd7302fe3b9a4a3a8305cba5afbc1ffc", null ],
      [ "target", "structflecs_1_1entity__view.html#ad4cc5b0c81948e7f89fbcb22c71037b7", null ],
      [ "target_for", "structflecs_1_1entity__view.html#a4e31a4fcc129f94afd46df63e772666d", null ],
      [ "to_constant", "structflecs_1_1entity__view.html#ga58a06a1f245b3b96165092ca16737df1", null ],
      [ "to_constant", "group__cpp__entities.html#ga58a06a1f245b3b96165092ca16737df1", null ],
      [ "to_json", "structflecs_1_1entity__view.html#ga30ca7153aeaa3eb012f44d8aa3374e89", null ],
      [ "to_json", "group__cpp__addons__json.html#ga30ca7153aeaa3eb012f44d8aa3374e89", null ],
      [ "try_get", "structflecs_1_1entity__view.html#adbdc382040cceb53ce535e300cdc43c3", null ],
      [ "try_get", "structflecs_1_1entity__view.html#affc0e8aa3a6c7e3335e96b2ce61c4112", null ],
      [ "try_get", "structflecs_1_1entity__view.html#a233d3c98a7a2b47261f2e46b70c2f328", null ],
      [ "try_get", "structflecs_1_1entity__view.html#a2a07ba0a74481ca70319e9bcabfcfd38", null ],
      [ "try_get", "structflecs_1_1entity__view.html#a66769cabaea72a9a31fb84af50a5710a", null ],
      [ "try_get", "structflecs_1_1entity__view.html#a5a6f839ba7fb59db40610d0e9799ab9e", null ],
      [ "try_get", "structflecs_1_1entity__view.html#a9846aac03aa60f5e3f87a5b1fc15b822", null ],
      [ "try_get_mut", "structflecs_1_1entity__view.html#ab5156fc60999b1f4318ae812e3b2fc5d", null ],
      [ "try_get_mut", "structflecs_1_1entity__view.html#a8491e2355033d76b6582f9b5d5c64093", null ],
      [ "try_get_mut", "structflecs_1_1entity__view.html#a9d6cd8aa1149d3cb16cf2214896b607a", null ],
      [ "try_get_mut", "structflecs_1_1entity__view.html#ace280816c70408c6cad613180d4e9ba7", null ],
      [ "try_get_mut", "structflecs_1_1entity__view.html#abd21775b44d51d95297a180016d1e2a4", null ],
      [ "try_get_mut", "structflecs_1_1entity__view.html#ae134b1cc36064c84a4db5b525f5e0e31", null ],
      [ "try_get_mut", "structflecs_1_1entity__view.html#ad35c298e174187789d09f04d1ea73d50", null ],
      [ "try_get_mut_second", "structflecs_1_1entity__view.html#acb870e431ba8de0a291609b9f8848d65", null ],
      [ "try_get_mut_second", "structflecs_1_1entity__view.html#a5ed6622a1f94d3bf57636971bf26d159", null ],
      [ "try_get_second", "structflecs_1_1entity__view.html#aecd4f73209a122ad59b92390c78fa770", null ],
      [ "try_get_second", "structflecs_1_1entity__view.html#a16862338008914173decdc3ef9e4a1f1", null ],
      [ "type", "structflecs_1_1entity__view.html#a02733f595103809e82ac3b1119ec7645", null ],
      [ "unit", "group__cpp__addons__meta.html#ga2bc94f1781c3f53ee9191cf26da588ae", null ],
      [ "quantity", "group__cpp__addons__meta.html#gac86161629bc421f597655579e8694b04", null ],
      [ "quantity", "group__cpp__addons__meta.html#ga4b3d8d87501d602f2911da0f0b473536", null ],
      [ "quantity", "group__cpp__addons__meta.html#ga0b531f451234e48028d84593a4a22a9f", null ],
      [ "unit", "group__cpp__addons__meta.html#ga5876427fe4e3cd6077cd03819d7758e7", null ],
      [ "unit_prefix", "group__cpp__addons__meta.html#ga72b3a9713d33456ff9ee3964f1122ec9", null ]
    ] ],
    [ "flecs::entity_builder< Self >", "structflecs_1_1entity__builder.html", [
      [ "add", "structflecs_1_1entity__builder.html#aec29c6103fe8ec34f2260e8269bdd8fc", null ],
      [ "add", "structflecs_1_1entity__builder.html#a378cf10142876b10354f3f3761676f4a", null ],
      [ "add", "structflecs_1_1entity__builder.html#a0f4b5dfcb8e444373fe51623510ea8ca", null ],
      [ "add", "structflecs_1_1entity__builder.html#a97a83b4d51ceb0004a5793e208e906ac", null ],
      [ "add", "structflecs_1_1entity__builder.html#a8f5e829cc6cdd42395436e447c078d52", null ],
      [ "add", "structflecs_1_1entity__builder.html#a78a6ed2ee64e83a66576a89b5170532d", null ],
      [ "add", "structflecs_1_1entity__builder.html#af0efcda21f6fd6871c7023dd008210a1", null ],
      [ "add_if", "structflecs_1_1entity__builder.html#a8599118f821b34753619d26a6dc13501", null ],
      [ "add_if", "structflecs_1_1entity__builder.html#a706f6b2ffa0bd3d013b8f07506f92ec3", null ],
      [ "add_if", "structflecs_1_1entity__builder.html#a1c571dff751ee47f3c5a95a431ece77f", null ],
      [ "add_if", "structflecs_1_1entity__builder.html#a7ab5e4aef52e28b8bce9b194774e5b33", null ],
      [ "add_if", "structflecs_1_1entity__builder.html#a9d651da4c0157c71e8e9bddf766bc34c", null ],
      [ "add_if", "structflecs_1_1entity__builder.html#a9ff2735c8ba886c032335be708315e96", null ],
      [ "add_second", "structflecs_1_1entity__builder.html#a9fc35623fba54ecc3a5a73cddc7b58d7", null ],
      [ "assign", "structflecs_1_1entity__builder.html#ab44c3bced7ca83b257ec5ddb2f9333de", null ],
      [ "assign", "structflecs_1_1entity__builder.html#a69d3b33488eac33d4ff91078b663394b", null ],
      [ "assign", "structflecs_1_1entity__builder.html#a28a4b39e70cd115196b5daafcb04ce20", null ],
      [ "assign", "structflecs_1_1entity__builder.html#a63f0abc060edce31fad865da12c772e5", null ],
      [ "assign", "structflecs_1_1entity__builder.html#a6cc427851ba7ce3c59ceda468f989bd5", null ],
      [ "assign", "structflecs_1_1entity__builder.html#ab8899ffde3b71d521d2b855fe8cbc283", null ],
      [ "assign", "structflecs_1_1entity__builder.html#a99d917441f96f26da3059996d94b9f4f", null ],
      [ "assign", "structflecs_1_1entity__builder.html#a3334988303481b0b78a878d92ed55c6b", null ],
      [ "assign", "structflecs_1_1entity__builder.html#a6f9f13eb014ece6c3e72b0bd83290a73", null ],
      [ "assign_second", "structflecs_1_1entity__builder.html#af0b40c5ee7a8a189b464fabe6bc627d7", null ],
      [ "assign_second", "structflecs_1_1entity__builder.html#a9df105c5f9b016690e92b391e0f65ad8", null ],
      [ "auto_override", "structflecs_1_1entity__builder.html#a45b772f4c004019272c35a5df3994106", null ],
      [ "auto_override", "structflecs_1_1entity__builder.html#ae855dda8007cee2d318be9ea6e808edf", null ],
      [ "auto_override", "structflecs_1_1entity__builder.html#ae83a78c02936ea236552bb1a92e99157", null ],
      [ "auto_override", "structflecs_1_1entity__builder.html#a153fb2651447dc3f4137b291a977f0eb", null ],
      [ "auto_override", "structflecs_1_1entity__builder.html#ada22fdcc9c1d18d1cc7ee94a696292a6", null ],
      [ "child_of", "structflecs_1_1entity__builder.html#a4bc696009d7dee0408c2676df89db6b5", null ],
      [ "child_of", "structflecs_1_1entity__builder.html#ac5ac854c3be562cfd4ff5c07b64e0363", null ],
      [ "depends_on", "structflecs_1_1entity__builder.html#ad1194ea6452b0b33c03f47e114a409d0", null ],
      [ "depends_on", "structflecs_1_1entity__builder.html#a79433c1ec01dd26b6e70ddf76b772585", null ],
      [ "depends_on", "structflecs_1_1entity__builder.html#ace125c47b515609467906f96163c0861", null ],
      [ "disable", "structflecs_1_1entity__builder.html#a04cf84a7131b162ba2b84ecaa552fb84", null ],
      [ "disable", "structflecs_1_1entity__builder.html#a8def0956e65d1875a55e074d8c708dca", null ],
      [ "disable", "structflecs_1_1entity__builder.html#ae589845d6f26fa740fd7eb8d70dfe7bf", null ],
      [ "disable", "structflecs_1_1entity__builder.html#a2ab0a844d5f4a0b1865578a2bf19af57", null ],
      [ "disable", "structflecs_1_1entity__builder.html#a5e9b68ad145c42dbf820807010b42f15", null ],
      [ "disable", "structflecs_1_1entity__builder.html#aad4e63fb80096e9cb50f84f54c12ed1e", null ],
      [ "emplace", "structflecs_1_1entity__builder.html#a1e51fec5a536bf1f800406bc6c2795ed", null ],
      [ "emplace_auto_override", "structflecs_1_1entity__builder.html#a2b975bffc8628a9603fd6f2774c9dc08", null ],
      [ "emplace_auto_override", "structflecs_1_1entity__builder.html#a02b34720fff76a1b9ff672aa962dcef2", null ],
      [ "enable", "structflecs_1_1entity__builder.html#a3bd3159a876072b275bf5ce3a071b95f", null ],
      [ "enable", "structflecs_1_1entity__builder.html#a45e4f02f1e5a677132c4075a5c90f50d", null ],
      [ "enable", "structflecs_1_1entity__builder.html#a5b8d20beb011c31f41de9627a19acb63", null ],
      [ "enable", "structflecs_1_1entity__builder.html#a5ccd8e62330f1a04f2a4942074d51912", null ],
      [ "enable", "structflecs_1_1entity__builder.html#ac184fced98e50c3d947a50a3b82746ba", null ],
      [ "enable", "structflecs_1_1entity__builder.html#a17d5969d188b9f1c65f2e746fc05db6f", null ],
      [ "entity_view", "structflecs_1_1entity__builder.html#a0d5b19b619f9d78bf53f9ed74b180173", null ],
      [ "entity_view", "structflecs_1_1entity__builder.html#a4a8996a0d9c528294da5bc6f22873841", null ],
      [ "insert", "structflecs_1_1entity__builder.html#a9a498296757c345b11115079fd8914d7", null ],
      [ "is_a", "structflecs_1_1entity__builder.html#a3963c4b9c5441f46edfef951cfd44d55", null ],
      [ "is_a", "structflecs_1_1entity__builder.html#a77ae0fae5526a20b3187a30bb294dc82", null ],
      [ "observe", "structflecs_1_1entity__builder.html#ab6050fb9a45b5bcbe5e38bdc9964d7e6", null ],
      [ "observe", "structflecs_1_1entity__builder.html#afa90b66fd65d2710e07007bd73e86339", null ],
      [ "observe", "structflecs_1_1entity__builder.html#a49e77241334232d5acb67fd92a40f6fc", null ],
      [ "observe", "structflecs_1_1entity__builder.html#a5d5576de6136754c371925634df684fa", null ],
      [ "observe", "structflecs_1_1entity__builder.html#a19adebc4c18a744e1258996ac333421e", null ],
      [ "observe", "structflecs_1_1entity__builder.html#a28ef5b21eb210f57bfef85462ac56b4d", null ],
      [ "remove", "structflecs_1_1entity__builder.html#a5e91c0fee61c9989ff11d2e28df83293", null ],
      [ "remove", "structflecs_1_1entity__builder.html#a8c9afcf9e1c26207f78f57430a48e1b5", null ],
      [ "remove", "structflecs_1_1entity__builder.html#ab59ded188639c071ce893f91701eb04c", null ],
      [ "remove", "structflecs_1_1entity__builder.html#a19cc5f971f1a45a93f92cd812be554bb", null ],
      [ "remove", "structflecs_1_1entity__builder.html#a191f9218a8fa5c2e9f235a91a4dc49a7", null ],
      [ "remove", "structflecs_1_1entity__builder.html#a1da22fbfb4d80e9b6291758d7a306f57", null ],
      [ "remove_second", "structflecs_1_1entity__builder.html#a404a701f159da50aa62c1104f8898423", null ],
      [ "scope", "structflecs_1_1entity__builder.html#a47a86bfaacdfba0fe44e7c5188a8d449", null ],
      [ "scope", "structflecs_1_1entity__builder.html#a9a98eb882db1004e8ef0ea4d04191d21", null ],
      [ "set", "structflecs_1_1entity__builder.html#abfe84f9ebd5f9ae23cd2e27682d7f10b", null ],
      [ "set", "structflecs_1_1entity__builder.html#a5344856be84e6fe5a638a896050d4b93", null ],
      [ "set", "structflecs_1_1entity__builder.html#a584c17375f7820fc678aac1e1acb6be9", null ],
      [ "set", "structflecs_1_1entity__builder.html#adcdd091aade64facfcfa2a45a34062c8", null ],
      [ "set", "structflecs_1_1entity__builder.html#a4898eb0f60a52a0bf2336025d61d9443", null ],
      [ "set", "structflecs_1_1entity__builder.html#a146289ece6a533e68b6a3a38d991099d", null ],
      [ "set", "structflecs_1_1entity__builder.html#a6dd543de232e2d9dcc7fab90c104f071", null ],
      [ "set", "structflecs_1_1entity__builder.html#a99a05333374dba34c0aa2fe9843d366f", null ],
      [ "set", "structflecs_1_1entity__builder.html#ac7a1b354c1f13c01e9898b012d2b34e8", null ],
      [ "set_auto_override", "structflecs_1_1entity__builder.html#a554515e6ae5dca1231c1627f0752512b", null ],
      [ "set_auto_override", "structflecs_1_1entity__builder.html#af6dd73f75e5483ad378c20f593210037", null ],
      [ "set_auto_override", "structflecs_1_1entity__builder.html#ab11f0e9f816e72133e48eaec63c7ae67", null ],
      [ "set_auto_override", "structflecs_1_1entity__builder.html#a20b11e2eb5c8b567e5e40b609c1fb4f2", null ],
      [ "set_auto_override", "structflecs_1_1entity__builder.html#abc567feffbfe417aadf8bf7cd131c236", null ],
      [ "set_auto_override", "structflecs_1_1entity__builder.html#a8415fc06bc3afec03a12746b7c975c4b", null ],
      [ "set_doc_brief", "structflecs_1_1entity__builder.html#ga8f84eea617a139d8a7a6cc52039d4078", null ],
      [ "set_doc_brief", "group__cpp__addons__doc.html#ga8f84eea617a139d8a7a6cc52039d4078", null ],
      [ "set_doc_color", "structflecs_1_1entity__builder.html#ga9cd9ef24259a552322746a84bbbb9a3c", null ],
      [ "set_doc_color", "group__cpp__addons__doc.html#ga9cd9ef24259a552322746a84bbbb9a3c", null ],
      [ "set_doc_detail", "structflecs_1_1entity__builder.html#gaffb31d7837dfc1c4dc3bae89659968d7", null ],
      [ "set_doc_detail", "group__cpp__addons__doc.html#gaffb31d7837dfc1c4dc3bae89659968d7", null ],
      [ "set_doc_link", "structflecs_1_1entity__builder.html#ga9898033ab60172b2ed5b675b99b96426", null ],
      [ "set_doc_link", "group__cpp__addons__doc.html#ga9898033ab60172b2ed5b675b99b96426", null ],
      [ "set_doc_name", "structflecs_1_1entity__builder.html#ga5820cd2803f99cc6ef41e1e5c0eec6a8", null ],
      [ "set_doc_name", "group__cpp__addons__doc.html#ga5820cd2803f99cc6ef41e1e5c0eec6a8", null ],
      [ "set_doc_uuid", "structflecs_1_1entity__builder.html#ga1f1be3c70cc2b1174a843ab35da5cf66", null ],
      [ "set_doc_uuid", "group__cpp__addons__doc.html#ga1f1be3c70cc2b1174a843ab35da5cf66", null ],
      [ "set_json", "structflecs_1_1entity__builder.html#gaf8f9794d1cca94722dbc8af8c2f97679", null ],
      [ "set_json", "group__cpp__addons__json.html#gaf8f9794d1cca94722dbc8af8c2f97679", null ],
      [ "set_json", "structflecs_1_1entity__builder.html#gae0dd6a23eb80e47ce2c17b24e9a01692", null ],
      [ "set_json", "group__cpp__addons__json.html#gae0dd6a23eb80e47ce2c17b24e9a01692", null ],
      [ "set_json", "structflecs_1_1entity__builder.html#ga80c1e161a667c02603ce7bd226fa7019", null ],
      [ "set_json", "group__cpp__addons__json.html#ga80c1e161a667c02603ce7bd226fa7019", null ],
      [ "set_json", "structflecs_1_1entity__builder.html#gafbf781155476437fcf38d37e2380f8a8", null ],
      [ "set_json", "group__cpp__addons__json.html#gafbf781155476437fcf38d37e2380f8a8", null ],
      [ "set_json", "structflecs_1_1entity__builder.html#gad6b8a4ab52df0cfbff91cf1a96896218", null ],
      [ "set_json", "group__cpp__addons__json.html#gad6b8a4ab52df0cfbff91cf1a96896218", null ],
      [ "set_json_second", "structflecs_1_1entity__builder.html#ga4c4de9b34edbf7fb3ef8dd1e56601a8c", null ],
      [ "set_json_second", "group__cpp__addons__json.html#ga4c4de9b34edbf7fb3ef8dd1e56601a8c", null ],
      [ "set_second", "structflecs_1_1entity__builder.html#aafededaae12672400a80760e75e937c3", null ],
      [ "set_second", "structflecs_1_1entity__builder.html#afed8c2ec34f0701611596c6d5ca2ff98", null ],
      [ "set_second", "structflecs_1_1entity__builder.html#a81e94bad637236db20f21608ef7613ed", null ],
      [ "slot", "structflecs_1_1entity__builder.html#a5ed232a47807a146194bcc2873d95100", null ],
      [ "slot_of", "structflecs_1_1entity__builder.html#ae903a0848a5e62a2f2d5df4126b3a958", null ],
      [ "slot_of", "structflecs_1_1entity__builder.html#a419cd6b824d5778c56140b424474821b", null ],
      [ "unit", "group__cpp__addons__meta.html#ga2bc94f1781c3f53ee9191cf26da588ae", null ],
      [ "with", "structflecs_1_1entity__builder.html#afc1787191dce47aa9a20af1c13840d17", null ],
      [ "with", "structflecs_1_1entity__builder.html#aaaf9f331066ed419e5b564fe16791ef5", null ],
      [ "with", "structflecs_1_1entity__builder.html#a99409ffe8c3d12dc7adaf50c66569ff7", null ],
      [ "quantity", "group__cpp__addons__meta.html#gac86161629bc421f597655579e8694b04", null ],
      [ "quantity", "group__cpp__addons__meta.html#ga4b3d8d87501d602f2911da0f0b473536", null ],
      [ "quantity", "group__cpp__addons__meta.html#ga0b531f451234e48028d84593a4a22a9f", null ],
      [ "unit", "group__cpp__addons__meta.html#ga5876427fe4e3cd6077cd03819d7758e7", null ],
      [ "unit_prefix", "group__cpp__addons__meta.html#ga72b3a9713d33456ff9ee3964f1122ec9", null ]
    ] ],
    [ "flecs::world::entity", "group__cpp__entities.html#ga544d341cf586c8af5915f6198d782601", null ],
    [ "flecs::world::entity", "group__cpp__entities.html#ga516bc5813331e8580f5e105a1349c672", null ],
    [ "flecs::world::entity", "group__cpp__entities.html#ga509a10bad742e72e1acb3aa0967203c1", null ],
    [ "flecs::world::id", "group__cpp__entities.html#ga74c9840d657c57410cebc5c0fe62903c", null ],
    [ "flecs::world::prefab", "group__cpp__entities.html#gac85030c68a4f438218d42b9ec3a2b450", null ],
    [ "flecs::world::prefab", "group__cpp__entities.html#gaf2175c4b55288f38daa081c2d6b95ec4", null ],
    [ "flecs::entity_view::to_constant", "group__cpp__entities.html#ga58a06a1f245b3b96165092ca16737df1", null ],
    [ "flecs::world::to_entity", "group__cpp__entities.html#gadae014c4a68b2f6ec1965ab944ae7932", null ]
];